@@ -179,10 +179,13 @@ class Client(object):
     @needs_admin_privs
     def get_users(self):
         """
+        Returns a list of dictionaries, each containing the attributes of a
+        different RabbitMQ user.
+
         :returns: a list of dictionaries, each representing a user. This
-            method is decorated with '@needs_admin_privs', and will raise
-            an error if the credentials used to set up the broker connection
-            do not have admin privileges.
+              method is decorated with '@needs_admin_privs', and will raise
+              an error if the credentials used to set up the broker connection
+              do not have admin privileges.
 
         """
 
@@ -194,8 +197,10 @@ class Client(object):
     ################################################
     def get_all_vhosts(self):
         """
+        Lists the names of all RabbitMQ vhosts.
+
         :returns: a list of dicts, each dict representing a vhost
-            on the broker.
+                on the broker.
 
         """
         vhosts = self.http.do_call(Client.urls['all_vhosts'], 'GET')
@@ -447,17 +452,36 @@ class Client(object):
         vhost = '%2F' if vhost == '/' else vhost
         path = Client.urls['queues_by_name'] % (vhost, name)
         queue = self.http.do_call(path,'GET')
-        depth = 0
-
-        if isinstance(queue, list):
-            for q in queue:
-                if q['name'] == name:
-                    depth = q['messages']
-        else:
-            depth = queue['messages']
+        depth = queue['messages']
 
         return depth
 
+    def get_queue_depths(self, vhost, names=None):
+        """
+        Get the number of messages currently sitting in either the queue
+        names listed in 'names', or all queues in 'vhost' if no 'names' are
+        given.
+
+        :param str vhost: Vhost where queues in 'names' live.
+        :param list names: OPTIONAL - Specific queues to show depths for. If
+                None, show depths for all queues in 'vhost'.
+        """
+
+        vhost = '%2F' if vhost == '/' else vhost
+        if not names:
+            # get all queues in vhost
+            path = Client.urls['queues_by_vhost'] % vhost
+            queues = self.http.do_call(path, 'GET')
+            for queue in queues:
+                depth = queue['messages']
+                print("\t%s: %s" % (queue, depth))
+        else:
+            # get the named queues only.
+            for name in names:
+                depth = self.get_queue_depth(vhost, name)
+                print("\t%s: %s" % (name, depth))
+
+
     def purge_queues(self, queues):
         """
         Purge all messages from one or more queues.
